==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexfieldlistviewitem.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXFIELDLISTVIEWITEM_H
#define KBIBTEXFIELDLISTVIEWITEM_H

#include <qlistview.h>
#include <bibtexentry.h>

class QString;
class BibTeXEntryField;

class KBibTeXFieldListViewItem : public QListViewItem
{
public:
    KBibTeXFieldListViewItem( BibTeXEntryField* field, QListView *parent, const char* name = NULL );
    ~KBibTeXFieldListViewItem();

    BibTeXEntryField* field();

    void updateItem();

private:
    BibTeXEntryField* m_field;

    void setTexts();
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexfieldlistviewitem.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXFIELDLISTVIEWITEM_H
#define KBIBTEXFIELDLISTVIEWITEM_H

#include <qlistview.h>
#include <bibtexentry.h>

class QString;
class BibTeX::BibTeXEntryField;

class KBibTeXFieldListViewItem : public QListViewItem
{
public:
    KBibTeXFieldListViewItem( BibTeX::BibTeXEntryField* field, QListView *parent, const char* name = NULL );
    ~KBibTeXFieldListViewItem();

    BibTeX::BibTeXEntryField* field();

    void updateItem();

private:
    BibTeX::BibTeXEntryField* m_field;

    void setTexts();
};

#endif
